@@ -41,6 +41,9 @@
 #include <algorithm>
 #include <numeric>
 #include <unordered_set>
+#include <exception>
+#include <stdexcept>
+#include <cassert>
 #include <math.h>
 #include <cmath>
 #include <stddef.h>
@@ -95,6 +98,8 @@ typedef void (*sig_t_)(int);
     #define omp_get_thread_num() 0
 #endif
 
+#define unexpected_error() throw std::runtime_error("Unexpected error. Please open an issue in GitHub.\n")
+
 
 /****************************************************************
     Data types and structs that are returned from this module
